@@ -18,10 +18,14 @@ PROPS = (
     "user_pictures_dir",
     "user_videos_dir",
     "user_music_dir",
+    "user_bin_dir",
+    "user_applications_dir",
     "user_runtime_dir",
     "site_data_dir",
     "site_config_dir",
     "site_cache_dir",
+    "site_state_dir",
+    "site_log_dir",
     "site_runtime_dir",
 )
 
